<?php
// This file is part of the Moodle module "EJSApp"
//
// EJSApp is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// EJSApp is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
//
// EJSApp has been developed by:
// - Luis de la Torre: ldelatorre@dia.uned.es
// - Ruben Heradio: rheradio@issi.uned.es
//
// at the Computer Science and Automatic Control, Spanish Open University
// (UNED), Madrid, Spain.

/**
 * Receives any .rec, .blk, .json, text or image file saved by an EjsS javascript lab
 * application and decides what to do with it:
 *  1) store it in the users' private files
 *  2) store it in the database (for users interactions only).
 *
 * @package    mod_ejsapp
 * @copyright  2012 Luis de la Torre and Ruben Heradio
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../config.php');
require_login();

global $DB, $CFG;

$uri = 'http://150.214.163.142/SARLABV8.0/gexlab';
$result simplexml_load_file($uri);
var_dump($result);

// Obtain the list of users in Moodle with Sarlab designer role
$sarlabdesignerroleid = $DB->get_field('role', 'id', array('shortname' => 'sarlabdesigner'));
$records = $DB->get_records('role_assignments', array('roleid' => $sarlabdesignerroleid));
$sarlabdesignerusersid = array();
foreach ($records as $record) {
    array_push($sarlabdesignerusersid, $record->userid);
}

// Obtain the list of users in Moodle with Sarlab manager role
$sarlabmanagerroleid = $DB->get_field('role', 'id', array('shortname' => 'sarlabmanager'));
$records = $DB->get_records('role_assignments', array('roleid' => $sarlabmanagerroleid));
$sarlabmanagerusersid = array();
foreach ($records as $record) {
    array_push($sarlabmanagerusersid, $record->userid);
}

// Ask Sarlab IRS for $sarlabirsdesignerusersid and $sarlabirsmanagerusersid
$sarlabirstoken = 'demo-101-irs-token';

$curl = curl_init('http://enlargeirs.dia.uned.es/designers');
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_USERPWD, $sarlabirstoken . ':');
curl_setopt($curl, CURLOPT_HTTPHEADER, array('Accept: application/xml;q=0.9, */*;q=0.8'));
$curl_response = curl_exec($curl);
curl_close($curl);
if ($curl_response !== false) {
    $xml_response = simplexml_load_string($curl_response);
    if ($xml_response) {
        $site_hostname = parse_url($CFG->wwwroot);
        $site_hostname = $site_hostname['host'];
        $sarlabirsdesignerusersid = [];
        $sarlabirsmanagerusersid = [];
        $record = new \stdClass();
        $record->contextid    = 1;
        $record->component    = '';
        $record->itemid       = 0;
        $record->timemodified = time();
        $record->modifierid   = 0;
        $record->sortorder    = 0;
        // Prepare lti users remote ids, remote hostname url and local ids
        $lti_users_hostname = $DB->get_fieldset_select('enrol_lti_users', 'serviceurl',
            "id > ?", array(0));
        if (!empty($lti_users_hostname)) {
            function fcn2(&$item) {
                $item = parse_url($item);
                $item = $item['host'];
            }
            array_walk($lti_users_hostname, "fcn2");
        }
        $lti_remote_users_id = $DB->get_fieldset_select('enrol_lti_users', 'sourceid',
            "id > ?", array(0));
        if (!empty($lti_remote_users_id)) {
            function fcn1(&$item) {
                $item = json_decode($item, true);
                $item = $item['data'];
                $item = $item['userid'];
            }
            array_walk($lti_remote_users_id, "fcn1");
        }
        $lti_users_id = $DB->get_fieldset_select('enrol_lti_users', 'userid',
            "id > ?", array(0));
        function update_role($record, $user_id, $sarlabroleid) {
            // Check whether the user is designer or manager and update role assignments
            global $DB;
            if (!$DB->record_exists('role_assignments', ['roleid' => $sarlabroleid,
                'userid' => $user_id])) {
                $record->roleid = $sarlabroleid;
                $record->userid = $user_id;
                $DB->insert_record('role_assignments', $record);
            }
            return $user_id;
        }
        foreach ($xml_response->item as $item) {
            $user_site_hostname = parse_url((string) $item->siteURL);
            $user_site_hostname = $user_site_hostname['host'];
            $user_id = (int) $item->user_id;
            if (strcmp($site_hostname, $user_site_hostname) == 0) {
                $level = (int)$item->level;
                if ($DB->record_exists('user', ['id' => $user_id])) { // this moodle's user
                    if ($level == 1) {
                        $sarlabirsdesignerusersid[] = update_role($record, $user_id, $sarlabdesignerroleid);
                    } else {
                        $sarlabirsmanagerusersid[] = update_role($record, $user_id, $sarlabmanagerroleid);
                    }
                } else { // LTI user?
                    // Check if the user info received from Sarlab corresponds to any LTI user
                    $origin_coincidence = array_search($user_site_hostname, $lti_users_hostname);
                    $user_id_coincidence = array_search($user_id, $lti_remote_users_id);
                    if ($origin_coincidence && $user_id_coincidence &&
                        ($origin_coincidence == $user_id_coincidence)) { // If so, continue
                        if ($level == 1) {
                            $sarlabirsdesignerusersid[] = update_role($record, $user_id, $sarlabdesignerroleid);
                        } else {
                            $sarlabirsmanagerusersid[] = update_role($record, $user_id, $sarlabmanagerroleid);
                        }
                    }
                }
            }
        }
        foreach ($sarlabdesignerusersid as $sarlabdesigneruserid) {
            if (!in_array($sarlabdesigneruserid, $sarlabirsdesignerusersid)) {
                $DB->delete_records('role_assignments', ['roleid' => $sarlabdesignerroleid,
                    'userid' => $sarlabdesigneruserid]);
            }
        }
        foreach ($sarlabmanagerusersid as $sarlabmanageruserid) {
            if (!in_array($sarlabmanageruserid, $sarlabirsmanagerusersid)) {
                $DB->delete_records('role_assignments', ['roleid' => $sarlabmanagerroleid,
                    'userid' => $sarlabmanageruserid]);
            }
        }
    }
}